==> nautilus-2.9.2.tar.gz: nautilus-2.9.2/src/file-manager/fm-actions.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* fm-actions.h
 *
 * Copyright (C) 2004  Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors: Alexander Larsson < alexl@redhat.com>
 */

#ifndef FM_ACTIONS_H
#define FM_ACTIONS_H

#define FM_ACTION_OPEN "Open"
#define FM_ACTION_OPEN_ALTERNATE "OpenAlternate"
#define FM_ACTION_OTHER_APPLICATION1 "OtherApplication1"
#define FM_ACTION_OTHER_APPLICATION2 "OtherApplication2"
#define FM_ACTION_NEW_FOLDER "New Folder"
#define FM_ACTION_PROPERTIES "Properties"
#define FM_ACTION_PROPERTIES_ACCEL "PropertiesAccel"
#define FM_ACTION_NO_TEMPLATES "No Templates"
#define FM_ACTION_EMPTY_TRASH "Empty Trash"
#define FM_ACTION_CUT "Cut"
#define FM_ACTION_COPY "Copy"
#define FM_ACTION_PASTE "Paste"
#define FM_ACTION_PASTE_FILES_INTO "Paste Files Into"
#define FM_ACTION_NEW_LAUNCHER "New Launcher"
#define FM_ACTION_RENAME "Rename"
#define FM_ACTION_DUPLICATE "Duplicate"
#define FM_ACTION_CREATE_LINK "Create Link"
#define FM_ACTION_SELECT_ALL "Select All"
#define FM_ACTION_TRASH "Trash"
#define FM_ACTION_DELETE "Delete"
#define FM_ACTION_SHOW_HIDDEN_FILES "Show Hidden Files"
#define FM_ACTION_RESET_BACKGROUND "Reset Background"
#define FM_ACTION_CONNECT_TO_SERVER_LINK "Connect To Server Link"
#define FM_ACTION_MOUNT_VOLUME "Mount Volume"
#define FM_ACTION_UNMOUNT_VOLUME "Unmount Volume"
#define FM_ACTION_SCRIPTS "Scripts"
#define FM_ACTION_NEW_DOCUMENTS "New Documents"
#define FM_ACTION_EMPTY_TRASH_CONDITIONAL "Empty Trash Conditional"
#define FM_ACTION_MANUAL_LAYOUT "Manual Layout"
#define FM_ACTION_TIGHTER_LAYOUT "Tighter Layout"
#define FM_ACTION_REVERSED_ORDER "Reversed Order"
#define FM_ACTION_CLEAN_UP "Clean Up"
#define FM_ACTION_KEEP_ALIGNED "Keep Aligned"
#define FM_ACTION_ARRANGE_ITEMS "Arrange Items"
#define FM_ACTION_STRETCH "Stretch"
#define FM_ACTION_UNSTRETCH "Unstretch"
#define FM_ACTION_ZOOM_ITEMS "Zoom Items"

#endif /* FM_ACTIONS_H */

==> nautilus_2.10.0.orig.tar.gz: nautilus-2.10.0/src/file-manager/fm-actions.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* fm-actions.h
 *
 * Copyright (C) 2004  Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors: Alexander Larsson < alexl@redhat.com>
 */

#ifndef FM_ACTIONS_H
#define FM_ACTIONS_H

#define FM_ACTION_OPEN "Open"
#define FM_ACTION_OPEN_ALTERNATE "OpenAlternate"
#define FM_ACTION_OTHER_APPLICATION1 "OtherApplication1"
#define FM_ACTION_OTHER_APPLICATION2 "OtherApplication2"
#define FM_ACTION_NEW_FOLDER "New Folder"
#define FM_ACTION_PROPERTIES "Properties"
#define FM_ACTION_PROPERTIES_ACCEL "PropertiesAccel"
#define FM_ACTION_NO_TEMPLATES "No Templates"
#define FM_ACTION_EMPTY_TRASH "Empty Trash"
#define FM_ACTION_CUT "Cut"
#define FM_ACTION_COPY "Copy"
#define FM_ACTION_PASTE "Paste"
#define FM_ACTION_PASTE_FILES_INTO "Paste Files Into"
#define FM_ACTION_NEW_LAUNCHER "New Launcher"
#define FM_ACTION_RENAME "Rename"
#define FM_ACTION_DUPLICATE "Duplicate"
#define FM_ACTION_CREATE_LINK "Create Link"
#define FM_ACTION_SELECT_ALL "Select All"
#define FM_ACTION_TRASH "Trash"
#define FM_ACTION_DELETE "Delete"
#define FM_ACTION_SHOW_HIDDEN_FILES "Show Hidden Files"
#define FM_ACTION_CONNECT_TO_SERVER_LINK "Connect To Server Link"
#define FM_ACTION_MOUNT_VOLUME "Mount Volume"
#define FM_ACTION_UNMOUNT_VOLUME "Unmount Volume"
#define FM_ACTION_EJECT_VOLUME "Eject Volume"
#define FM_ACTION_SCRIPTS "Scripts"
#define FM_ACTION_NEW_DOCUMENTS "New Documents"
#define FM_ACTION_EMPTY_TRASH_CONDITIONAL "Empty Trash Conditional"
#define FM_ACTION_MANUAL_LAYOUT "Manual Layout"
#define FM_ACTION_TIGHTER_LAYOUT "Tighter Layout"
#define FM_ACTION_REVERSED_ORDER "Reversed Order"
#define FM_ACTION_CLEAN_UP "Clean Up"
#define FM_ACTION_KEEP_ALIGNED "Keep Aligned"
#define FM_ACTION_ARRANGE_ITEMS "Arrange Items"
#define FM_ACTION_STRETCH "Stretch"
#define FM_ACTION_UNSTRETCH "Unstretch"
#define FM_ACTION_ZOOM_ITEMS "Zoom Items"

#endif /* FM_ACTIONS_H */
